import org.junit.Assert;
import org.junit.Test;


public class CheckbookTest {
    private Checkbook checkbook1 = new Checkbook(100.00);
    private Checkbook checkbook2 = new Checkbook(30.00);
    private Payee owner1 = new Payee();
    private Payee owner2 = new Payee();
    private Transaction transactionDebit1 = new Transaction(" ", owner1, TransactionType.DEBIT, 100.00);
    private Transaction transactionCredit1 = new Transaction(" ", owner1, TransactionType.CREDIT, 50.00);
    private Transaction transactionDebit2 = new Transaction(" ", owner2, TransactionType.DEBIT, 100.00);
    private Transaction transactionCredit2 = new Transaction(" ", owner2, TransactionType.CREDIT, 50.00);

    @org.junit.Before
    public void setUp() throws Exception {
        checkbook1.add(transactionCredit1);
        checkbook1.add(transactionDebit1);
        checkbook2.add(transactionCredit2);
        checkbook2.add(transactionDebit2);
    }

    @org.junit.After
    public void tearDown() throws Exception {
    }

    @Test
    public void test1Add() {
        Assert.assertEquals(2, checkbook1.size());
    }

    @Test
    public void test2Add() {
        checkbook1.add(new Transaction("", new Payee(), TransactionType.DEBIT, 1.00));
        int expected = 3;
        int actual = checkbook1.size();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test3Add() {
        checkbook2.add(new Transaction("", owner1, TransactionType.DEBIT, 1.00));
        checkbook2.add(new Transaction("", owner1, TransactionType.DEBIT, 1.50));
        int expected = 4;
        int actual = checkbook2.size();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1Remove() {
        checkbook1.remove(transactionCredit1);
        int expected = 1;
        int actual = checkbook1.size();
        Assert.assertEquals(expected, actual);

    }

    @Test
    public void test2Remove() {
        checkbook1.remove(transactionCredit1);
        checkbook1.remove(transactionDebit1);
        int expected = 0;
        int actual = checkbook1.size();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1contains() {
        Assert.assertTrue(checkbook1.contains(transactionCredit1));
    }

    @Test
    public void test2contains() {
        Assert.assertTrue(checkbook1.contains(transactionDebit1));
    }

    @Test
    public void test3contains() {
        Assert.assertTrue(checkbook2.contains(transactionCredit2));
    }

    @Test
    public void test1isEmpty() {
        Assert.assertFalse(checkbook2.isEmpty());
    }

    @Test
    public void test2isEmpty() {
        Checkbook check = new Checkbook();
        Assert.assertTrue(check.isEmpty());
    }

    @Test
    public void test3isEmpty() {
        Assert.assertFalse(checkbook1.isEmpty());
    }

    @Test
    public void test1Iterator() {
        Assert.assertTrue(checkbook1.iterator().hasNext());
    }

    @Test
    public void test2Iterator() {
        Checkbook check = new Checkbook();
        Assert.assertFalse(check.iterator().hasNext());
    }

    @Test
    public void test1CheckbookValue() {
        Assert.assertEquals(100.00, checkbook1.checkbookValue(), .01);
    }

    @Test
    public void test2CheckbookValue() {
        Double expected = 30.00;
        Double actual = checkbook2.checkbookValue();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1ToArray() {
        int expected = 2;
        int actual = checkbook1.toArray().length;
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test2ToArray() {
        int expected = 2;
        int actual = checkbook2.toArray().length;
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test3ToArray() {
        Checkbook check = new Checkbook();
        int expected = 0;
        int actual = check.toArray().length;
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1getTransactionForDate() {
        Transaction[] expected = {transactionCredit1, transactionDebit1};
        Transaction[] actual = checkbook1.getTransactionForDate(transactionCredit1.getDate());
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test2getTransactionForDate() {
        Transaction[] expected = {transactionCredit2, transactionDebit2};
        Transaction[] actual = checkbook2.getTransactionForDate(transactionCredit2.getDate());
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1getAllTransactionsForPayee() {
        Transaction[] expected = {transactionDebit1, transactionCredit1};
        Transaction[] actual = checkbook1.getAllTransactionsForPayee(owner1);
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test2getAllTransactionsForPayee() {
        Transaction[] expected = {transactionDebit2, transactionCredit2};
        Transaction[] actual = checkbook2.getAllTransactionsForPayee(owner2);
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test3getAllTransactionsForPayee() {
        Transaction[] expected = {transactionDebit1, transactionCredit1};
        Transaction[] actual = checkbook1.getAllTransactionsForPayee(owner1);
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1getAllDebitTransactions() {
        Transaction[] expected = {transactionDebit2};
        Transaction[] actual = checkbook2.getAllDebitTransactions();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test2getAllDebitTransactions() {
        Transaction[] expected = {transactionDebit1};
        Transaction[] actual = checkbook1.getAllDebitTransactions();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test3getAllDebitTransactions() {
        Checkbook checkbook = new Checkbook();
        Transaction transactionDebit = new Transaction(" ", owner1, TransactionType.DEBIT, 100.00);
        checkbook.add(transactionDebit);
        Transaction[] expected = {transactionDebit};
        Transaction[] actual = checkbook.getAllDebitTransactions();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1getAllCreditTransactions() {
        Transaction[] expected = {transactionCredit1};
        Transaction[] actual = checkbook1.getAllCreditTransactions();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test2getAllCreditTransactions() {
        Transaction[] expected = {transactionCredit2};
        Transaction[] actual = checkbook2.getAllCreditTransactions();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test3getAllCreditTransactions() {
        Checkbook checkbook = new Checkbook();
        Transaction transactionCredit = new Transaction(" ", owner1, TransactionType.CREDIT, 100.00);
        checkbook.add(transactionCredit);
        Transaction[] expected = {transactionCredit};
        Transaction[] actual = checkbook.getAllCreditTransactions();
        Assert.assertEquals(expected, actual);
    }

    @Test
    public void test1Clear() {
        checkbook2.clear();
        Assert.assertEquals(0, checkbook2.size());
    }

    @Test
    public void test2Clear() {
        checkbook1.clear();
        Assert.assertEquals(0, checkbook1.size());
    }


}